@@ -10,7 +10,7 @@ my $gen = highlightc::CodeGenerator_getInstance(highlightc::HTML);
 
 
 #initialize the generator with a colour theme and the language definition
-$gen->initStyle("/usr/share/highlight/themes/kwrite.style");
+$gen->initTheme("/usr/share/highlight/themes/kwrite.style");
 $gen->initLanguage("/usr/share/highlight/langDefs/c.lang");
 
 #set some parameters
@@ -21,8 +21,8 @@ $gen->setEncoding("ISO-8859-1");
 my $output=$gen->generateCString("int main(int argc, char **argv) {\n".
                            " HighlightApp app;\n".
                            " return app.run(argc, argv);\n".
-                           "}\n", "Test string");
+                           "}\n");
 print $output;
 
 # clear the instance
-highlightc::CodeGenerator_deleteInstance();
\ No newline at end of file
+highlightc::CodeGenerator_deleteInstance();
