@@ -78,9 +78,9 @@ CmdLineOptions::CmdLineOptions(int argc, char *argv[]):
         {OPT_RTF, 0,0,S_OPT_RTF},
         {OPT_TEX,0, 0,S_OPT_TEX},
         {OPT_LATEX,0, 0,S_OPT_LATEX},
-        {OPT_XSLFO,0, 0,S_OPT_XSLFO},
         {OPT_ANSI,0, 0,S_OPT_ANSI},
         {OPT_XML,0, 0,S_OPT_XML},
+        {OPT_XTERM256,0, 0,S_OPT_XTERM256},
         {OPT_BATCHREC,1,0,S_OPT_BATCHREC},
         {OPT_FRAGMENT,0,0,S_OPT_FRAGMENT},
         {OPT_ANCHORS, 0,0,S_OPT_ANCHORS },
@@ -199,15 +199,15 @@ CmdLineOptions::CmdLineOptions(int argc, char *argv[]):
         case S_OPT_LATEX:
           outputType=highlight::LATEX;
           break;
-        case S_OPT_XSLFO:
-          std::cerr << "\nWARNING: XSL-FO support has been discontinued since"
-                    << " release 2.4.4. XML is generated instead.\n\n";
         case S_OPT_XML:
           outputType=highlight::XML;
           break;
         case S_OPT_ANSI:
           outputType=highlight::ANSI;
           break;
+        case S_OPT_XTERM256:
+          outputType=highlight::XTERM256;
+          break;
         case S_OPT_BATCHREC:
           opt_batch_mode = true;
           readDirectory(string(optarg));
@@ -403,7 +403,6 @@ string CmdLineOptions::getOutFileSuffix()const{
       case highlight::RTF:   return ".rtf";
       case highlight::TEX:
       case highlight::LATEX: return ".tex";
-      case highlight::XSLFO: return ".xml";
       case highlight::XML:   return ".xml";
       case highlight::ANSI:   return ".ansi";
       default:    return ".html";
@@ -602,12 +601,12 @@ void CmdLineOptions::loadConfigurationFile()
           outputType=highlight::TEX;
       } else if (getFlag(userConfig.getParameter(OPT_LATEX))) {
           outputType=highlight::LATEX;
-      } else if (getFlag(userConfig.getParameter(OPT_XSLFO))) {
-          outputType=highlight::XML;
       } else if (getFlag(userConfig.getParameter(OPT_ANSI))) {
           outputType=highlight::ANSI;
       } else if (getFlag(userConfig.getParameter(OPT_XML))) {
-            outputType=highlight::XML;
+          outputType=highlight::XML;
+      } else if (getFlag(userConfig.getParameter(OPT_XTERM256))) {
+          outputType=highlight::XTERM256;
       }
     }
 }
