@@ -22,12 +22,12 @@
 #include "rtfgenerator.h"
 #include "latexgenerator.h"
 #include "texgenerator.h"
-//#include "xslfogenerator.h"
 #include "xmlgenerator.h"
 #include "re/Matcher.h"
 
 #ifndef __WXMSW__
   #include "ansigenerator.h"
+  #include "xterm256generator.h"
 #endif
 
 
@@ -55,7 +55,6 @@ CodeGenerator * CodeGenerator::getInstance(OutputType type) {
       case RTF:
         generator = new RtfGenerator ();
         break;
-      case XSLFO:  // TODO remove
       case XML:
         generator = new XmlGenerator();
         break;
@@ -63,6 +62,9 @@ CodeGenerator * CodeGenerator::getInstance(OutputType type) {
       case ANSI:
         generator = new AnsiGenerator ();
         break;
+      case XTERM256:
+        generator = new Xterm256Generator ();
+        break;
       #endif
       default:
         break;
@@ -149,6 +151,11 @@ bool CodeGenerator::initTheme(const string& themePath) {
   return docStyle.load(themePath);
 }
 
+bool CodeGenerator::hasWhiteBGColour(){
+    StyleColour bgCol = docStyle.getBgColour();
+    return bgCol.getRed(HTML) == "ff" && bgCol.getGreen(HTML) == "ff"&&bgCol.getBlue(HTML) == "ff";
+}
+
 const string& CodeGenerator::getStyleName(){
   return themePath;
 }
@@ -221,7 +228,7 @@ const string CodeGenerator::getBaseFont() const {
           return "tt";
           break;
        default:
-          return "Courier";
+          return "Courier New";
      }
    } else {
      return baseFont ;
@@ -292,7 +299,6 @@ State CodeGenerator::getState(const string &s, unsigned int searchPos)
   string::size_type pos2 = s.find(' ', pos);
   int result=_UNKNOWN;
   StringTools::str2num<int>(result, s.substr(pos, pos2-pos), std::dec);
-
   return (State)result;
 }
 
@@ -390,6 +396,12 @@ State CodeGenerator::getCurrentState ()
       token= c;
       return _WS;
   }
+//std::cerr << "getCurrentState c="<<c<<"\n";
+
+  /** TODO
+      COMMENT ... END 2 einträge in langdef (ML_COMMENT_START=regex(), ML_COMMENT_END=regex())
+      weil comment sonst als identifier erkannt wird
+  */
 
   // Test if a regular expression was found at the current position
   if (!regexGroups.empty()){
@@ -412,6 +424,7 @@ State CodeGenerator::getCurrentState ()
 
   unsigned int symbolLength;
   size_t symbolPos;
+  size_t symbolFind;
   bool found=false;
   string symbols=langInfo.getSymbolString();
 
@@ -420,7 +433,11 @@ State CodeGenerator::getCurrentState ()
   // before keywords, because alphabetic chars may be part of symbols, too
   while ((symbolPos!= string::npos) && (!found))
     {
-      symbolLength=symbols.find(' ', symbolPos)-symbolPos;
+      symbolFind = symbols.find(' ', symbolPos);
+      if (symbolFind==string::npos) break;
+      symbolLength=symbolFind-symbolPos;
+      //std::cerr << "sub3 s.."<<symbols<<" pos="<< symbolPos<<" len="<<symbolLength<<" find"<<symbols.find(' ', symbolPos)<< " string::npos="<<string::npos;
+
       token = symbols.substr(symbolPos, symbolLength);
 
       // Abfrage nach Leerzeichen in SymbolString verhindert falsches
@@ -433,6 +450,7 @@ State CodeGenerator::getCurrentState ()
         symbolPos = symbols.find_first_not_of(' ',symbols.find(' ',symbolPos));
       }
     }
+  //std::cerr << "symbols found="<<found<<" token = "<<token<<"\n";
 
   // dirty workaround stuff in here
   if (found) {
