@@ -248,7 +248,10 @@ class CodeGenerator
     string &getTitle();
 
     /** \param p HTML anchor prefix */
-    void CodeGenerator::setHTMLAnchorPrefix(const string & p);
+    void setHTMLAnchorPrefix(const string & p);
+
+    /** \return true if background colour of style is white */
+    bool hasWhiteBGColour();
 
 protected:
     CodeGenerator(highlight::OutputType type);
