@@ -40,9 +40,9 @@ void ElementStyle::set(const string & elementStyleString){
   valueStream >> r;
   valueStream >> g;
   valueStream >> b;
-  colour.setRedValue(r);
-  colour.setGreenValue(g);
-  colour.setBlueValue(b);
+  colour.setRed(r);
+  colour.setGreen(g);
+  colour.setBlue(b);
   while ( valueStream >> attr)
     {
       if (attr=="italic")
