@@ -81,9 +81,9 @@ enum OutputType {
   TEX,
   LATEX,
   RTF,
-  XSLFO,
   XML,
-  ANSI
+  ANSI,
+  XTERM256
 };
 
 }
