@@ -175,7 +175,13 @@ static enum
     // Solaris compilation fix
     extern "C" {
      char *getenv(const char *name);
-     int  strncmp(const char *s1, const char *s2, int n);
+
+     #ifdef __MACOSX
+       int  strncmp(const char *s1, const char *s2, long unsigned int n);
+     #else
+       int  strncmp(const char *s1, const char *s2, int n);
+     #endif
+
     }
    // extern char *getenv(const char *name);
    // extern int  strncmp(const char *s1, const char *s2, int n);
