@@ -56,9 +56,8 @@ class HtmlGenerator  : public highlight::CodeGenerator
     virtual void insertLineNumber(bool insertNewLine=true);
 
     /** Print document header
-       \param  title Title of the document
     */
-    string getHeader(const string &title);
+    string getHeader();
 
     /** Print document body*/
     void printBody();
@@ -82,6 +81,11 @@ class HtmlGenerator  : public highlight::CodeGenerator
     */
      void setAttachAnchors(bool b){ attachAnchors = b; }
 
+     /**
+       \param  prefix anchor prefix
+    */
+     void setAnchorPrefix(const string & prefix){ anchorPrefix = prefix; }
+
      /**
        \param  b set true line numbers should be replaced by list items
     */
@@ -92,9 +96,6 @@ class HtmlGenerator  : public highlight::CodeGenerator
     /** some strings which are similar in HTML and XHTML*/
     string brTag, hrTag, idAttr, fileSuffix;
 
-    /** HTML footer */
-    //string HTML_FOOTER;
-
     /** caches style definition */
     string styleDefinitionCache;
 
@@ -126,6 +127,8 @@ class HtmlGenerator  : public highlight::CodeGenerator
     /** test if anchors should be appied to line numbers*/
     bool attachAnchors;
 
+    string anchorPrefix;
+
     /**\return text formatting attributes in HTML format */
     string  formatStyleAttributes(const string & elemName, const ElementStyle & elem);
 
