@@ -114,6 +114,8 @@ class LanguageDefinition  {
     /** \return regular expressions */
      vector<RegexElement*>& getRegexElements()  {return regex;};
 
+    const string & getDescription () {return langDesc;}
+
   private:
     // string containing symbols and their IDs of the programming language
     string symbolString;
@@ -121,6 +123,9 @@ class LanguageDefinition  {
     // path to laoded language definition
     string currentPath;
 
+    // Language description
+    string langDesc;
+
     KeywordMap keywords;
 
     vector <string> keywordClasses;
