@@ -39,6 +39,8 @@ void HighlightApp::printVersionInfo()
        << "\n Copyright (C) 2002-2004 Benjamin Kaufmann <hume at c-plusplus.de>"
        << "\n\n Regex library (1.05.02)"
        << "\n Copyright (C) 2003-2006 Jeffery Stuart <stuart at cs.unr.edu>"
+       << "\n\n xterm 256 color matching functions"
+       << "\n Copyright (C) 2006 Wolfgang Frisch <wf at frexx.de>"
        << "\n\n This software is released under the terms of the GNU General "
        << "Public License."
        << "\n For more information about these matters, see the file named "
@@ -103,18 +105,15 @@ void HighlightApp::printDebugInfo(highlight::LanguageDefinition &lang,
    cerr << "\nKEYWORDS:\n";
    highlight::KeywordMap::iterator it;
    highlight::KeywordMap keys=lang.getKeywords();
-   for (it=keys.begin(),
-        cerr << it->first << "("<< it->second << ")";
-        it!=keys.end();it++) {
-          cerr << ", "<<it->first
-               << "("<< it->second << ")";
+   for (it=keys.begin(); it!=keys.end(); it++) {
+          cerr << " "<< it->first << "("<< it->second << ")";
    }
    cerr <<"\n\n";
 }
 
 void HighlightApp::printConfigInfo(const string& configFile)
 {
- cout << "\nRoot paths (modified by --" OPT_DATADIR  " and --" OPT_ADDDATADIR "):\n";
+ cout << "\nRoot paths (modify with --" OPT_DATADIR  " and --" OPT_ADDDATADIR "):\n";
  cout << "  Data directory:         "<<dataDir.getDir()<<"\n";
  if (!dataDir.getAdditionalDataDir().empty())
      cout << "  User defined directory: "<<dataDir.getAdditionalDataDir()<<"\n";
@@ -122,15 +121,20 @@ void HighlightApp::printConfigInfo(const string& configFile)
  cout << "  Language definitions:   "<<dataDir.getLangDefDir()<<"\n";
  cout << "  Colour themes:          "<<dataDir.getThemeDir()<<"\n";
  cout << "  Indentation schemes:    "<<dataDir.getIndentSchemesDir()<<"\n";
+ cout << "  Help files:             "<<dataDir.getHelpMsgDir()<<"\n";
  cout << "  Configuration files:    "<<dataDir.getConfDir()<<"\n";
  cout << "\nUser configuration:       "<<configFile<<"\n\n";
 
  #ifdef USE_LOCAL_GETOPT
    cout << "Compiler directive USE_LOCAL_GETOPT defined.\n";
  #endif
+ #ifdef USE_FN_MATCH
+   cout << "Compiler directive USE_FN_MATCH defined.\n";
+ #endif
  #ifdef HL_DATA_DIR
    cout << "Compiler directive HL_DATA_DIR = " <<HL_DATA_DIR<< "\n";
  #endif
+
  cout << endl;
 }
 
@@ -329,6 +333,14 @@ int HighlightApp::run(int argc, char**argv){
     return EXIT_FAILURE;
   }
 
+   if (   !options.quietMode()
+       && !generator->hasWhiteBGColour()
+       && (   options.getOutputType() == highlight::RTF
+           || options.getOutputType() == highlight::ANSI
+           || options.getOutputType() == highlight::XTERM256)){
+    cerr << "highlight: Chosen output format only supports white background\n";
+  }
+
   if (!options.getIndentScheme().empty()){
     string indentSchemePath =
               dataDir.searchForIndentScheme(options.getIndentScheme()+".indent");
