@@ -3,12 +3,11 @@
   "
   Let me start by saying this file is pretty big. If you feel up to it, you can
   try making changes yourself, but you would be better off to just email me at
-  stuart@cs.unr.edu if you think there is a bug, or have something useful you
-  would like added (I'm working on the unicode port right now, just give me some
-  time). This project is very "near and dear" to me, so I am fairly quick to make
-  bug fixes. The header files for Pattern and Matcher are fairly well documented
-  and the function names are pretty self-explanatory, but if you are having any
-  trouble, feel free to email me at stuart@cs.unr.edu.
+  stuart@cs.ucdavis.edu if you think there is a bug, or have something useful you
+  would like added. This project is very "near and dear" to me, so I am fairly
+  quick to make bug fixes. The header files for Pattern and Matcher are fairly
+  well documented and the function names are pretty self-explanatory, but if you
+  are having any trouble, feel free to email me at stuart@cs.ucdavis.edu.
 
   If you email me, make sure you put something like C++RE in the subject because
   I tend to delete email if I don't recognize the name and the subject is
@@ -21,12 +20,12 @@
 
   @author   Jeffery Stuart
   @since    November 2004
-  @version  0.01a
+  @version  1.05.02
 */
 
 #include "Pattern.h"
 #include "Matcher.h"
-#include <ctype.h>
+#include <cstring>
 #include <algorithm>
 
 std::map<std::string, Pattern *> Pattern::compiledPatterns;
@@ -41,24 +40,11 @@ const unsigned long Pattern::DOT_MATCHES_ALL        = 0x04;
 const unsigned long Pattern::MULTILINE_MATCHING     = 0x08;
 const unsigned long Pattern::UNIX_LINE_MODE         = 0x10;
 
-inline static int tolower(const char c)
-{
-  return ((c >= 'A' && c <= 'Z') ? (c - 'A' + 'a') : c);
-}
-
-static int str_icmp(const char * a, const char * b)
-{
-  while (*a || *b)
-  {
-    char c1 = tolower(*a);
-    char c2 = tolower(*b);
-    if (c1 > c2) return 1;
-    if (c1 < c2) return -1;
-    ++a;
-    ++b;
-  }
-  return 0;
-}
+#ifdef _WIN32
+  #define str_icmp stricmp
+#else
+  #define str_icmp strcasecmp
+#endif
 
 Pattern::Pattern(const std::string & rhs)
 {
@@ -73,6 +59,22 @@ Pattern::Pattern(const std::string & rhs)
 // convenience function in case we want to add any extra debugging output
 void Pattern::raiseError()
 {
+  switch (pattern[curInd - 1])
+  {
+  case '*':
+  case ')':
+  case '+':
+  case '?':
+  case ']':
+  case '}':
+    fprintf(stderr, "%s\n%*c^\n", pattern.c_str(), curInd - 1, ' ');
+    fprintf(stderr, "Syntax Error near here. Possible unescaped meta character.\n");
+    break;
+  default:
+    fprintf(stderr, "%s\n%*c^\n", pattern.c_str(), curInd - 1, ' ');
+    fprintf(stderr, "Syntax Error near here. \n");
+    break;
+  }
   error = 1;
 }
 NFANode * Pattern::registerNode(NFANode * node)
@@ -289,11 +291,11 @@ std::string Pattern::parseClass()
       t = parseClass();
       ret = classUnion(ret, t);
     }
-    else if (ch == '-')
+    /*else if (ch == '-')
     {
       raiseError();
       curInd = pattern.size();
-    }
+    }*/
     else if (ch == '&' && curInd < (int)pattern.size() && pattern[curInd] == '&')
     {
       if (pattern[++curInd] != '[')
@@ -404,16 +406,16 @@ std::string Pattern::parseClass()
 std::string Pattern::parsePosix()
 {
   std::string s7 = pattern.substr(curInd, 7);
-  if (s7 == "{Lower}")  return "abcdefghijklmnopqrstuvwxyz";
-  if (s7 == "{Upper}")  return "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
-  if (s7 == "{Alpha}")  return "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ";
-  if (s7 == "{Digit}")  return "0123456789";
-  if (s7 == "{Alnum}")  return "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
-  if (s7 == "{Punct}")  return "!\"#$%&'()*+,-./:;<=>?@[\\]^_`{|}~";
-  if (s7 == "{Graph}")  return "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789!\"#$%&'()*+,-./:;<=>?@[\\]^_`{|}~";
-  if (s7 == "{Print}")  return "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789!\"#$%&'()*+,-./:;<=>?@[\\]^_`{|}~";
-  if (s7 == "{Blank}")  return " \t";
-  if (s7 == "{Space}")  return " \t\n\x0B\f\r";
+  if (s7 == "{Lower}")  { curInd += 7; return "abcdefghijklmnopqrstuvwxyz";                                                                       }
+  if (s7 == "{Upper}")  { curInd += 7; return "ABCDEFGHIJKLMNOPQRSTUVWXYZ";                                                                       }
+  if (s7 == "{Alpha}")  { curInd += 7; return "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ";                                             }
+  if (s7 == "{Digit}")  { curInd += 7; return "0123456789";                                                                                       }
+  if (s7 == "{Alnum}")  { curInd += 7; return "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";                                   }
+  if (s7 == "{Punct}")  { curInd += 7; return "!\"#$%&'()*+,-./:;<=>?@[\\]^_`{|}~";                                                               }
+  if (s7 == "{Graph}")  { curInd += 7; return "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789!\"#$%&'()*+,-./:;<=>?@[\\]^_`{|}~"; }
+  if (s7 == "{Print}")  { curInd += 7; return "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789!\"#$%&'()*+,-./:;<=>?@[\\]^_`{|}~"; }
+  if (s7 == "{Blank}")  { curInd += 7; return " \t";                                                                                              }
+  if (s7 == "{Space}")  { curInd += 7; return " \t\n\x0B\f\r";                                                                                    }
   if (s7 == "{Cntrl}")
   {
     int i;
@@ -423,15 +425,17 @@ std::string Pattern::parsePosix()
     s += " ";
     for (i = 0; i <= 0x1F; ++i) s[i] = i;
     s[0x20] = 0x7F;
+    curInd += 7;
     return s;
   }
   if (s7 == "{ASCII}")
   {
     std::string s(0x80, ' ');
     for (int i = 0; i < 0x80; ++i) s[i] = i;
+    curInd += 7;
     return s;
   }
-  if (pattern.substr(curInd, 8) == "{XDigit}") return "abcdefABCDEF0123456789";
+  if (pattern.substr(curInd, 8) == "{XDigit}") { curInd += 8; return "abcdefABCDEF0123456789"; }
   raiseError();
   return "";
 }
@@ -457,8 +461,8 @@ NFANode * Pattern::parseBackref()
     raiseError();
     return registerNode(new NFAReferenceNode(-1));
   }
-  curInd = ci - 1;
-  return registerNode(new NFAReferenceNode(oldRef));
+  curInd = ci;
+  return registerNode(new NFAReferenceNode(ref));
 
   #undef is_dig
   #undef to_int
@@ -689,18 +693,14 @@ NFANode * Pattern::parse(const bool inParen, const bool inOr, NFANode ** end)
     {
       ++curInd;
       --groupCount;
-      if      (pattern[curInd]           == ':')   { noncap = 1;  ++curInd;    grc = ++nonCapGroupCount;  }
-      else if (pattern[curInd]           == '=')   { ++curInd;     ahead = 1;  pos = 1;                   }
-      else if (pattern[curInd]           == '!')   { ++curInd;     ahead = 1;  pos = 0;                   }
-      else if (pattern.substr(curInd, 2) == "<=")  { curInd += 2;  return parseBehind(1, end);            }
-      else if (pattern.substr(curInd, 2) == "<!")  { curInd += 2;  return parseBehind(0, end);            }
-      else if (pattern[curInd]           == '>')   { ++curInd;     indep = 1;                             }
-      else                                         { raiseError(); return NULL;                           }
-      if (noncap)
-      {
-        grc = -grc;
-        cur = start = registerNode(new NFAGroupHeadNode(grc));
-      }
+      if      (pattern[curInd]           == ':')   { noncap = 1; ++curInd;     grc = --nonCapGroupCount; }
+      else if (pattern[curInd]           == '=')   { ++curInd;     ahead = 1;  pos = 1;                  }
+      else if (pattern[curInd]           == '!')   { ++curInd;     ahead = 1;  pos = 0;                  }
+      else if (pattern.substr(curInd, 2) == "<=")  { curInd += 2;  return parseBehind(1, end);           }
+      else if (pattern.substr(curInd, 2) == "<!")  { curInd += 2;  return parseBehind(0, end);           }
+      else if (pattern[curInd]           == '>')   { ++curInd;     indep = 1;                            }
+      else                                         { raiseError(); return NULL;                          }
+      if (noncap) cur = start = registerNode(new NFAGroupHeadNode(grc));
       else        cur = start = registerNode(new NFASubStartNode);
     }
     else cur = start = registerNode(new NFAGroupHeadNode(grc));
@@ -742,15 +742,14 @@ NFANode * Pattern::parse(const bool inParen, const bool inOr, NFANode ** end)
         case '7':
         case '8':
         case '9': next = parseBackref(); break;
-        case 'A': ++curInd; next = new NFAStartOfInputNode;     break;
-        case 'B': ++curInd; next = new NFAWordBoundaryNode(0);  break;
-        case 'b': ++curInd; next = new NFAWordBoundaryNode(1);  break;
-        case 'G': ++curInd; next = new NFAEndOfMatchNode;       break;
+        case 'A': ++curInd; next = registerNode(new NFAStartOfInputNode);     break;
+        case 'B': ++curInd; next = registerNode(new NFAWordBoundaryNode(0));  break;
+        case 'b': ++curInd; next = registerNode(new NFAWordBoundaryNode(1));  break;
+        case 'G': ++curInd; next = registerNode(new NFAEndOfMatchNode);       break;
         case 'Z': eoi = 1;
-        case 'z': ++curInd; next = new NFAEndOfInputNode(eoi);  break;
+        case 'z': ++curInd; next = registerNode(new NFAEndOfInputNode(eoi));  break;
         default:
           t = parseEscape(inv, quo);
-          //printf("inv quo classes { %c %c %s }\n", inv ? 't' : 'f', quo ? 't' : 'f', t.c_str());
           if (!quo)
           {
             if (t.size() > 1 || inv)
@@ -783,7 +782,7 @@ NFANode * Pattern::parse(const bool inParen, const bool inOr, NFANode ** end)
       {
         NFACIClassNode * clazz = new NFACIClassNode();
         std::string s = parseClass();
-        for (int i = 0; i < (int)s.size(); ++i) clazz->vals[s[i]] = 1;
+        for (int i = 0; i < (int)s.size(); ++i) clazz->vals[tolower(s[i])] = 1;
         next = registerNode(clazz);
       }
       break;
@@ -803,7 +802,7 @@ NFANode * Pattern::parse(const bool inParen, const bool inOr, NFANode ** end)
         NFANode * end, * t1, * t2;
         t1 = parse(1, 0, &end);
         if (!t1) raiseError();
-        else if (dynamic_cast<NFAGroupHeadNode*>(t1) != NULL && (t2 = quantifyGroup(t1, end, grc)) != NULL)
+        else if (t1->isGroupHeadNode() && (t2 = quantifyGroup(t1, end, grc)) != NULL)
         {
           cur->next = t2;
           cur = t2->next;
@@ -864,7 +863,10 @@ NFANode * Pattern::parse(const bool inParen, const bool inOr, NFANode ** end)
       else                                          next = registerNode(new NFACharNode(ch));
       break;
     }
-    if (next) cur = cur->next = quantify(next);
+    if (next)
+    {
+      cur = cur->next = quantify(next);
+    }
   }
   if (inParen) raiseError();
   else
@@ -901,7 +903,7 @@ Pattern * Pattern::compile(const std::string & pattern, const unsigned long mode
     }
     else
     {
-      if (dynamic_cast<NFAStartOfInputNode*>(p->head) == NULL)
+      if (!(p->head && p->head->isStartOfInputNode()))
       {
         NFANode * n = p->registerNode(new NFAStartNode);
         n->next = p->head;
@@ -936,14 +938,13 @@ Pattern * Pattern::compileAndKeep(const std::string & pattern, const unsigned lo
   return ret;
 }
 std::string Pattern::replace(const std::string & pattern, const std::string & str,
-                             const std::string & replaceWith, const unsigned long mode)
+                             const std::string & replacementText, const unsigned long mode)
 {
   std::string ret;
   Pattern * p = Pattern::compile(pattern, mode);
-
   if (p)
   {
-    ret = p->replace(str, replaceWith);
+    ret = p->replace(str, replacementText);
     delete p;
   }
   return ret;
@@ -953,7 +954,7 @@ std::vector<std::string> Pattern::split(const std::string & pattern, const std::
                               const unsigned long limit, const unsigned long mode)
 {
   std::vector<std::string> ret;
-  Pattern * p = Pattern::compile(pattern);
+  Pattern * p = Pattern::compile(pattern, mode);
   if (p)
   {
     ret = p->split(str, keepEmptys, limit);
@@ -1041,9 +1042,12 @@ Pattern::~Pattern()
   if (head) head->findAllNodes(nodes);
   */
   if (matcher) delete matcher;
-  for (std::map<NFANode*, bool>::iterator it = nodes.begin(); it != nodes.end(); ++it) delete it->first;
+  for (std::map<NFANode*, bool>::iterator it = nodes.begin(); it != nodes.end(); ++it)
+  {
+    delete it->first;
+  }
 }
-std::string Pattern::replace(const std::string & str, const std::string & replaceWith)
+std::string Pattern::replace(const std::string & str, const std::string & replacementText)
 {
   int li = 0;
   std::string ret = "";
@@ -1052,7 +1056,7 @@ std::string Pattern::replace(const std::string & str, const std::string & replac
   while (matcher->findNextMatch())
   {
     ret += str.substr(li, matcher->getStartingIndex() - li);
-    ret += matcher->replaceWithGroups(replaceWith);
+    ret += matcher->replaceWithGroups(replacementText);
     li = matcher->getEndingIndex();
   }
   ret += str.substr(li);
@@ -1061,12 +1065,13 @@ std::string Pattern::replace(const std::string & str, const std::string & replac
 }
 std::vector<std::string> Pattern::split(const std::string & str, const bool keepEmptys, const unsigned long limit)
 {
+  unsigned long lim = (limit == 0 ? MAX_QMATCH : limit);
   int li = 0;
   std::vector<std::string> ret;
 
   matcher->setString(str);
 
-  while (matcher->findNextMatch())
+  while (matcher->findNextMatch() && ret.size() < lim)
   {
     if (matcher->getStartingIndex() == 0 && keepEmptys) ret.push_back("");
     if ((matcher->getStartingIndex() != matcher->getEndingIndex()) || keepEmptys)
@@ -1124,17 +1129,13 @@ int NFACharNode::match(const std::string & str, Matcher * matcher, const int cur
 
 // NFACICharNode
 
-#define to_lower(x) (((x) >= 'A' && (x) <= 'Z') ? ((x) - 'A' + 'a') : (x))
-
-NFACICharNode::NFACICharNode(const char c) { ch = to_lower(c); }
+NFACICharNode::NFACICharNode(const char c) { ch = tolower(c); }
 int NFACICharNode::match(const std::string & str, Matcher * matcher, const int curInd) const
 {
-  if (curInd < (int)str.size() && to_lower(str[curInd]) == ch) return next->match(str, matcher, curInd + 1);
+  if (curInd < (int)str.size() && tolower(str[curInd]) == ch) return next->match(str, matcher, curInd + 1);
   return -1;
 }
 
-#undef to_lower
-
 // NFAStartNode
 
 NFAStartNode::NFAStartNode() { }
@@ -1309,8 +1310,6 @@ int NFAClassNode::match(const std::string & str, Matcher * matcher, const int cu
 
 // NFACIClassNode
 
-#define to_lower(x) (((x) >= 'A' && (x) <= 'Z') ? ((x) - 'A' + 'a') : (x))
-
 NFACIClassNode::NFACIClassNode(const bool invert)
 {
   inv = invert;
@@ -1318,11 +1317,11 @@ NFACIClassNode::NFACIClassNode(const bool invert)
 NFACIClassNode::NFACIClassNode(const std::string & clazz, const bool invert)
 {
   inv = invert;
-  for (int i = 0; i < (int)clazz.size(); ++i) vals[to_lower(clazz[i])] = 1;
+  for (int i = 0; i < (int)clazz.size(); ++i) vals[tolower(clazz[i])] = 1;
 }
 int NFACIClassNode::match(const std::string & str, Matcher * matcher, const int curInd) const
 {
-  if (curInd < (int)str.size() && ((vals.find(to_lower(str[curInd])) != vals.end()) ^ inv))
+  if (curInd < (int)str.size() && ((vals.find(tolower(str[curInd])) != vals.end()) ^ inv))
   {
     return next->match(str, matcher, curInd + 1);
   }
@@ -1442,10 +1441,10 @@ int NFAReferenceNode::match(const std::string & str, Matcher * matcher, const in
 {
   int len = matcher->ends[gi] - matcher->starts[gi];
   int ni = -1;
-  if      (gi < 1 || matcher->ends[gi] < matcher->starts[gi] || len == 0)             ni = curInd;
-  else if (curInd + len > (int)str.size())                                            return -1;
-  else if (str.substr(curInd, len) != str.substr(matcher->starts[gi], len))  return -1;
-  else                                                                                ni = curInd + len;
+  if      (gi < 1 || matcher->ends[gi] < matcher->starts[gi] || len == 0)   ni = curInd;
+  else if (curInd + len > (int)str.size())                                  return -1;
+  else if (str.substr(curInd, len) != str.substr(matcher->starts[gi], len)) return -1;
+  else                                                                      ni = curInd + len;
 
   return next->match(str, matcher, ni);
 }
