@@ -24,9 +24,9 @@ namespace highlight {
 string RtfGenerator::formatStyleAttributes( const ElementStyle & col)
 {
   stringstream s;
-  s  << "\\red"<< col.getColour().getRTFRedValue()
-     << "\\green"<<col.getColour().getRTFGreenValue()
-     << "\\blue"<<col.getColour().getRTFBlueValue()
+  s  << "\\red"<< col.getColour().getRed(RTF)
+     << "\\green"<<col.getColour().getGreen(RTF)
+     << "\\blue"<<col.getColour().getBlue(RTF)
      << ";";
 
   return s.str();
@@ -53,38 +53,58 @@ string  RtfGenerator::getCloseTag(const ElementStyle &elem)
 }
 
 RtfGenerator::RtfGenerator()
- : CodeGenerator(RTF)
+ : CodeGenerator(RTF),
+  pageSize("a4")
 {
-  styleTagOpen.push_back(getOpenTag(STANDARD, docStyle.getDefaultStyle()));
-  styleTagOpen.push_back(getOpenTag(STRING, docStyle.getStringStyle()));
-  styleTagOpen.push_back(getOpenTag(NUMBER, docStyle.getNumberStyle()));
-  styleTagOpen.push_back(getOpenTag(SL_COMMENT, docStyle.getSingleLineCommentStyle()));
-  styleTagOpen.push_back(getOpenTag(ML_COMMENT,docStyle.getCommentStyle()));
-  styleTagOpen.push_back(getOpenTag(ESC_CHAR, docStyle.getEscapeCharStyle()));
-  styleTagOpen.push_back(getOpenTag(DIRECTIVE, docStyle.getDirectiveStyle()));
-  styleTagOpen.push_back(getOpenTag(DIRECTIVE_STRING, docStyle.getDirectiveStringStyle()));
-  styleTagOpen.push_back(getOpenTag(LINENUMBER, docStyle.getLineStyle()));
-  styleTagOpen.push_back(getOpenTag(SYMBOL, docStyle.getSymbolStyle()));
-
-  styleTagClose.push_back(getCloseTag(docStyle.getDefaultStyle()));
-  styleTagClose.push_back(getCloseTag(docStyle.getStringStyle()));
-  styleTagClose.push_back(getCloseTag(docStyle.getNumberStyle()));
-  styleTagClose.push_back(getCloseTag(docStyle.getSingleLineCommentStyle()));
-  styleTagClose.push_back(getCloseTag(docStyle.getCommentStyle()));
-  styleTagClose.push_back(getCloseTag(docStyle.getEscapeCharStyle()));
-  styleTagClose.push_back(getCloseTag(docStyle.getDirectiveStyle()));
-  styleTagClose.push_back(getCloseTag(docStyle.getDirectiveStringStyle()));
-  styleTagClose.push_back(getCloseTag(docStyle.getLineStyle()));
-  styleTagClose.push_back(getCloseTag(docStyle.getSymbolStyle()));
-
   newLineTag = "\\par\\pard\n";
   spacer = " ";
+
+  // Page dimensions
+  psMap["a3"] = PageSize(16837,23811);
+  psMap["a4"] = PageSize(11905,16837);
+  psMap["a5"] = PageSize(8390,11905);
+
+  psMap["b4"] = PageSize(14173,20012);
+  psMap["b5"] = PageSize(9977,14173);
+  psMap["b6"] = PageSize(7086,9977);
+
+  psMap["letter"] = PageSize(12240,15840);
+  psMap["legal"] = PageSize(12240,20163);
 }
 
+
+bool RtfGenerator::initTheme(const string& themePath) {
+   bool result = CodeGenerator::initTheme(themePath);
+
+   styleTagOpen.push_back(getOpenTag(STANDARD, docStyle.getDefaultStyle()));
+   styleTagOpen.push_back(getOpenTag(STRING, docStyle.getStringStyle()));
+   styleTagOpen.push_back(getOpenTag(NUMBER, docStyle.getNumberStyle()));
+   styleTagOpen.push_back(getOpenTag(SL_COMMENT, docStyle.getSingleLineCommentStyle()));
+   styleTagOpen.push_back(getOpenTag(ML_COMMENT,docStyle.getCommentStyle()));
+   styleTagOpen.push_back(getOpenTag(ESC_CHAR, docStyle.getEscapeCharStyle()));
+   styleTagOpen.push_back(getOpenTag(DIRECTIVE, docStyle.getDirectiveStyle()));
+   styleTagOpen.push_back(getOpenTag(DIRECTIVE_STRING, docStyle.getDirectiveStringStyle()));
+   styleTagOpen.push_back(getOpenTag(LINENUMBER, docStyle.getLineStyle()));
+   styleTagOpen.push_back(getOpenTag(SYMBOL, docStyle.getSymbolStyle()));
+
+   styleTagClose.push_back(getCloseTag(docStyle.getDefaultStyle()));
+   styleTagClose.push_back(getCloseTag(docStyle.getStringStyle()));
+   styleTagClose.push_back(getCloseTag(docStyle.getNumberStyle()));
+   styleTagClose.push_back(getCloseTag(docStyle.getSingleLineCommentStyle()));
+   styleTagClose.push_back(getCloseTag(docStyle.getCommentStyle()));
+   styleTagClose.push_back(getCloseTag(docStyle.getEscapeCharStyle()));
+   styleTagClose.push_back(getCloseTag(docStyle.getDirectiveStyle()));
+   styleTagClose.push_back(getCloseTag(docStyle.getDirectiveStringStyle()));
+   styleTagClose.push_back(getCloseTag(docStyle.getLineStyle()));
+   styleTagClose.push_back(getCloseTag(docStyle.getSymbolStyle()));
+
+   return result;
+ }
+
 RtfGenerator::~RtfGenerator()
 {}
 
-string RtfGenerator::getHeader(const string & title)
+string RtfGenerator::getHeader()
 {
   return string();
 }
@@ -92,18 +112,11 @@ string RtfGenerator::getHeader(const string & title)
 void RtfGenerator::printBody()
 {
 
-// -- Kafka begins
-/*
-   *out << "{\\rtf1\\ansi\\uc0 \\deff1"
-         << "{\\fonttbl{\\f1\\fmodern\\fprq1\\fcharset0 Courier;}}"
-         << "{\\colortbl;";
-*/
  *out << "{\\rtf1\\ansi\\uc0 \\deff1"
        << "{\\fonttbl{\\f1\\fmodern\\fprq1\\fcharset0 " ;
  *out << this->getBaseFont() ;
  *out << ";}}"
       << "{\\colortbl;";
-// -- Kafka ends
 
   *out << formatStyleAttributes(docStyle.getDefaultStyle());
 
@@ -135,21 +148,18 @@ void RtfGenerator::printBody()
       *out << formatStyleAttributes(docStyle.getKeywordStyle(keywordClasses[i]));
   }
 
-// -- Kafka begins
-/*
-  *out << "}\n{\\info }\\paperw11900\\paperh16820\\margl560\\margr560\\margt840"
-        << "\\margb840\\widowctrl\\ftnbj\\aenddoc\\formshade \\fet0\\sectd"
-        << "\\linex0\\endnhere\\plain\\f1\\fs20\n\\pard ";
-*/
-  *out << "}\n{\\info }\\paperw11900\\paperh16820\\margl560\\margr560\\margt840"
-        << "\\margb840\\widowctrl\\ftnbj\\aenddoc\\formshade \\fet0\\sectd"
-        << "\\linex0\\endnhere\\plain\\f1\\fs" ;
-  int fontSize = StringTools::str2int(this->getBaseFontSize())*2; // RTF needs double amount
-  *out << ((fontSize)? fontSize: 20);
+  *out << "}\n";
+
+  *out  << "\\paperw"<< psMap[pageSize].width <<"\\paperh"<< psMap[pageSize].height
+        << "\\margl1134\\margr1134\\margt1134\\margb1134\\sectd" // page margins
+        << "\\plain\\f1\\fs" ;  // Font formatting
+  int fontSize=0;
+  StringTools::str2num<int>(fontSize, this->getBaseFontSize(), std::dec);
+  *out << ((fontSize)? fontSize*2: 20);  // RTF needs double amount
   *out << "\n\\pard ";
-// -- Kafka ends
 
   processRootState();
+
   *out << "}}"<<endl;
 }
 
@@ -192,7 +202,6 @@ string RtfGenerator::maskCharacter(unsigned char c)
       }
       break;
 
-
     case AUML_LC:
       return "\\'e4";
       break;
@@ -267,7 +276,6 @@ string RtfGenerator::maskCharacter(unsigned char c)
       return "\\'df";
       break;
 
-
     default :
       {
        string m;
@@ -285,5 +293,8 @@ string RtfGenerator::getMatchingCloseTag(unsigned int styleID){
   return getCloseTag(docStyle.getKeywordStyle(langInfo.getKeywordClasses()[styleID]));
 }
 
+void RtfGenerator::setPageSize(const string & ps){
+    if (psMap.count(ps)) pageSize = ps;  // Default: DIN A4
+}
 
 }
