@@ -17,20 +17,16 @@
 
 #include "stringtools.h"
 
-#include <sstream>
 #include <iostream>
 
-// Avoid problems with isspace and UTF-8 characters, use iswspace instead
-//#include <cctype>
+// Avoid problems with isspace and UTF-8 characters, use iswspace
 #include <wctype.h>
 
 
 using namespace std;
 
 namespace StringTools
-  {
-// Make a lowercase copy of s:
-// (C) Bruce Eckel, Thinking in C++ Vol 2
+{
 
 string lowerCase(const string& s)
 {
@@ -43,14 +39,6 @@ string lowerCase(const string& s)
   return r;
 }
 
-int str2int(string s, bool assureGreaterZero)
-{
-  istringstream os(s);
-  int intVal;
-  os >> intVal;
-  return (assureGreaterZero && intVal<0) ? 0 : intVal;
-}
-
  bool isAlpha(unsigned char c)
  {
    return (iswalpha(c) || c == '_');
@@ -101,7 +89,7 @@ vector<string> splitString(const string& s, unsigned char delim){
   do {
      if (oldPos-pos) results.push_back (s.substr(oldPos, pos-oldPos));
      oldPos=pos+1;
-      pos=s.find(delim, pos+1);
+     pos=s.find(delim, pos+1);
   } while (pos!=string::npos);
   results.push_back (s.substr(oldPos));
 
