@@ -45,10 +45,10 @@ string XHtmlGenerator::getHeaderStart(const string &title){
 }
 
 
-string XHtmlGenerator::getHeader(const string &title)
+string XHtmlGenerator::getHeader()
 {
   ostringstream os;
-  os << getHeaderStart((title.empty()) ? "Source file" : title );
+  os << getHeaderStart(docTitle);
 
   if (langInfo.getSyntaxHighlight()) {
     if (includeStyleDef) {
