@@ -46,9 +46,8 @@ class XHtmlGenerator : public highlight::HtmlGenerator
   private:
 
     /** prints document header
-       \param  title Title of the document
     */
-    string getHeader(const string &title);
+    string getHeader();
 
     string getHeaderStart(const string &title);
 
