@@ -57,9 +57,9 @@ string XmlGenerator::getStyleDefinition()
         ostringstream os;
         os << "\n<style>\n"
            << "\t<bgcolor value=\""
-           << (docStyle.getBgColour().getHexRedValue())
-           << (docStyle.getBgColour().getHexGreenValue())
-           << (docStyle.getBgColour().getHexBlueValue())
+           << (docStyle.getBgColour().getRed(XML))
+           << (docStyle.getBgColour().getGreen(XML))
+           << (docStyle.getBgColour().getBlue(XML))
            << "\" />\n";
         os << "\t<font size=\"" << getBaseFontSize();
         os << "\" family=\"" << getBaseFont() << "\" />\n";
@@ -92,9 +92,9 @@ string XmlGenerator::formatStyleAttributes(const string & elemName,
     s  << "\t<class name=\""
        << elemName
        <<"\" color=\""
-       << (elem.getColour().getHexRedValue())
-       << (elem.getColour().getHexGreenValue())
-       << (elem.getColour().getHexBlueValue()  )
+       << (elem.getColour().getRed(XML))
+       << (elem.getColour().getGreen(XML))
+       << (elem.getColour().getBlue(XML))
        << "\" bold=\""
        << ( elem.isBold() ? "true" :"false" )
        << "\" italic=\""
@@ -113,14 +113,16 @@ string  XmlGenerator::getCloseTag(const string& styleName ){
     return "</"+styleName+">";
 }
 
-string XmlGenerator::getHeader(const string & title)
+string XmlGenerator::getHeader()
 {
     ostringstream header;
     header << "<?xml version=\"1.0\"";
     if (encodingDefined()) {
         header << " encoding=\"" << encoding << "\"";
     }
-    header << "?>\n<document>" << getStyleDefinition();
+    header << "?>\n<document>";
+    header << "\n<title>" << docTitle << "</title>";
+    header << getStyleDefinition();
     return header.str();
 }
 
@@ -167,18 +169,6 @@ string XmlGenerator::maskCharacter(unsigned  char c)
     }
 }
 
-/*string XmlGenerator::getNewLine(){
-  string nlStr;
-  if (currentState!=_UNKNOWN){
-      nlStr+=styleTagClose[getStyleID(currentState, currentKeywordClass)];
-  }
-  nlStr += newLineTag;
-  if (currentState!=_UNKNOWN){
-      nlStr+=styleTagOpen[getStyleID(currentState, currentKeywordClass)];
-  }
-  return nlStr;
-}
-*/
 string XmlGenerator::getMatchingOpenTag(unsigned int styleID){
     return getOpenTag(langInfo.getKeywordClasses()[styleID]);
 }
